"""add stage tracking to AAT workflow templates

Revision ID: db9a82bc2020
Revises: 75349359d3b6
Create Date: 2023-03-14 16:40:44.773932

"""
from alembic import op


# revision identifiers, used by Alembic.
revision = "db9a82bc2020"
down_revision = "75349359d3b6"
branch_labels = None
depends_on = None


old_condor = """nraorsync://$(SBIN_PATH)/pycapo,"""
new_condor = """nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/update_stage,"""

old_carta_sh = b"""#!/bin/sh
set -o errexit

export HOME=$_CONDOR_SCRATCH_DIR
{{#remote-cv}}
export CAPO_PATH=$(readlink -f $_CONDOR_SCRATCH_DIR)
export CAPO_PROFILE={{profile}}
{{/remote-cv}}
fetch_foundation(){
  ../productfetcher{{product_locator}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \\;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""
new_carta_sh = b"""#!/bin/sh
set -o errexit

export HOME=$_CONDOR_SCRATCH_DIR
{{#remote-cv}}
export CAPO_PATH=$(readlink -f $_CONDOR_SCRATCH_DIR)
export CAPO_PROFILE={{profile}}
{{/remote-cv}}
fetch_foundation(){
  ../update_stage FETCH
  ../productfetcher{{fetch_args}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \\;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
  ../update_stage FETCH --complete
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}


"""

old_dl_sh = """#!/bin/sh
set -o errexit
chmod 770 .

./productfetcher --for-download {{#sdm_only}}--sdm-only{{/sdm_only}}{{^multiple_fetch}} --product-locator $2{{/multiple_fetch}}{{#multiple_fetch}}{{product_locator}}{{/multiple_fetch}}

./deliver{{#create_tar_file}} --tar{{/create_tar_file}}{{#username}} -u {{username}}{{/username}} {{#destination_directory}} -l {{destination_directory}}{{/destination_directory}} -r . --prefix $1
"""
new_dl_sh = """#!/bin/sh
set -o errexit
chmod 770 .

./update_stage FETCH
./productfetcher --for-download {{#sdm_only}}--sdm-only{{/sdm_only}}{{^multiple_fetch}} --product-locator $2{{/multiple_fetch}}{{#multiple_fetch}}{{product_locator}}{{/multiple_fetch}}
./update_stage FETCH --complete

./update_stage DELIVER
./deliver{{#create_tar_file}} --tar{{/create_tar_file}}{{#username}} -u {{username}}{{/username}} {{#destination_directory}} -l {{destination_directory}}{{/destination_directory}} -r . --prefix $1
./update_stage DELIVER --complete
"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{old_condor}', E'{new_condor}')::bytea
        WHERE filename in ('carta.condor', 'download.condor')
        """
    )
    conn = op.get_bind()
    conn.execute(
        f"""
            UPDATE workflow_templates
            SET content = %s WHERE filename='carta.sh'
            """,
        new_carta_sh,
    )

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{new_dl_sh}'
        WHERE filename = 'download.sh'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{new_condor}', E'{old_condor}')::bytea
        WHERE filename in ('carta.condor', 'download.condor')
        """
    )
    conn = op.get_bind()
    conn.execute(
        f"""
            UPDATE workflow_templates
            SET content = %s WHERE filename='carta.sh'
            """,
        old_carta_sh,
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_dl_sh}'
        WHERE filename = 'download.sh'
        """
    )
